/*
kyippiemail.cpp
GPL'd, by Sebastian Kienzl <zap@scene.at>
*/

#include "kyippiemail.h"

KApplication *mykapp;
QString mailfile;

KYippieMail::KYippieMail() : KTopLevelWidget()
{
    KIconLoader *icload = mykapp->getIconLoader();

    nomail = icload->loadIcon( "ynomail.xpm", 24, 24 );
    mail1 = icload->loadIcon( "ymail1.xpm", 24, 24 );
    mail2 = icload->loadIcon( "ymail2.xpm", 24, 24 );
    
    pixtimer = new QTimer();
    connect( pixtimer, SIGNAL( timeout() ), SLOT( pixSwap() ) );
    pixstatus = 0;
    
    checktimer = new QTimer();
    connect( checktimer, SIGNAL( timeout() ), SLOT( checkMail() ) );
    checktimer->start( 5000, false );
    checkMail();
    
    popup = new QPopupMenu();
    popup->insertItem( "&About", this, SLOT( about() ) );
    popup->insertItem( "&Quit", mykapp, SLOT( quit() ) );
    
    KWM::setDockWindow( winId() );
}

KYippieMail::~KYippieMail()
{
    delete popup;
    delete checktimer;
    delete pixtimer;
}

void KYippieMail::paintEvent( QPaintEvent * )
{
    if( newmail ) {
        if( pixstatus )
            bitBlt( this, 0, 0, &mail1 );
        else
            bitBlt( this, 0, 0, &mail2 );
        pixstatus ^= 1;
    }
    else {
        bitBlt( this, 0, 0, &nomail );
    }
}

void KYippieMail::mousePressEvent( QMouseEvent *m )
{
    if( m->button() == RightButton ) {
        popup->popup( QPoint( this->x() + m->x(), this->y() + m->y() ) );
        popup->exec();
    }
}

void KYippieMail::checkMail()
{
    QFile mail( mailfile );
    if( mail.exists() ) {
        if( mail.size() ) {
            newmail = true;
            pixtimer->start( 1000, false );
        }
        else {
            if( newmail ) {
                newmail = false;
                pixtimer->stop();
                repaint();
            }
            else
                newmail = false;
        }
    }
    else {
        setBackgroundColor( red );
    }
}

void KYippieMail::pixSwap()
{
    repaint();
}

void KYippieMail::about()
{
    KMsgBox::message( 0, "About",
                      "KYippieMail by Sebastian Kienzl (zap@scene.at)\n\n" \
                      "This little thingie will start to blink as soon as\n" \
                      "$MAIL gets bigger than 0 bytes in size.\n" );
}


int main( int argc, char *argv[] )
{
    if( !( mailfile = getenv( "MAIL" ) ) ) {
        debug( "environment 'MAIL' is not set!\n" );
        return 1;
    }
    mykapp = new KApplication( argc, argv, "kyippiemail" );
    KYippieMail topl;
    mykapp->setMainWidget( &topl );
    topl.show();
    return mykapp->exec();
}
